# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/course/enrollment_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.course import enrollment_pb2 as eolymp_dot_course_dot_enrollment__pb2
from eolymp.wellknown import direction_pb2 as eolymp_dot_wellknown_dot_direction__pb2
from eolymp.wellknown import expression_pb2 as eolymp_dot_wellknown_dot_expression__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&eolymp/course/enrollment_service.proto\x12\reolymp.course\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\x1e\x65olymp/course/enrollment.proto\x1a eolymp/wellknown/direction.proto\x1a!eolymp/wellknown/expression.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"F\n\x15\x43reateEnrollmentInput\x12-\n\nenrollment\x18\x01 \x01(\x0b\x32\x19.eolymp.course.Enrollment\"/\n\x16\x43reateEnrollmentOutput\x12\x15\n\renrollment_id\x18\x01 \x01(\t\"\xe8\x01\n\x15UpdateEnrollmentInput\x12\x39\n\x05patch\x18\x01 \x03(\x0e\x32*.eolymp.course.UpdateEnrollmentInput.Patch\x12\x15\n\renrollment_id\x18\x02 \x01(\t\x12-\n\nenrollment\x18\x03 \x01(\x0b\x32\x19.eolymp.course.Enrollment\"N\n\x05Patch\x12\x07\n\x03\x41LL\x10\x00\x12\x0f\n\x0b\x41SSIGNMENTS\x10\x01\x12\x13\n\x0f\x41SSIGNMENTS_ADD\x10\x02\x12\x16\n\x12\x41SSIGNMENTS_REMOVE\x10\x03\"\x18\n\x16UpdateEnrollmentOutput\".\n\x15\x44\x65leteEnrollmentInput\x12\x15\n\renrollment_id\x18\x01 \x01(\t\"\x18\n\x16\x44\x65leteEnrollmentOutput\"\xbf\x03\n\x14ListEnrollmentsInput\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12;\n\x07\x66ilters\x18( \x01(\x0b\x32*.eolymp.course.ListEnrollmentsInput.Filter\x12:\n\x04sort\x18\x32 \x01(\x0e\x32,.eolymp.course.ListEnrollmentsInput.Sortable\x12*\n\x05order\x18\x33 \x01(\x0e\x32\x1b.eolymp.wellknown.Direction\x12/\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32\x1f.eolymp.course.Enrollment.Extra\x1a\x99\x01\n\x06\x46ilter\x12*\n\x02id\x18\n \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x31\n\tmember_id\x18\x0b \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x30\n\x08group_id\x18\x0c \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\"\x17\n\x08Sortable\x12\x0b\n\x07\x44\x45\x46\x41ULT\x10\x00\"P\n\x15ListEnrollmentsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12(\n\x05items\x18\x02 \x03(\x0b\x32\x19.eolymp.course.Enrollment\"a\n\x17\x44\x65scribeEnrollmentInput\x12\x15\n\renrollment_id\x18\x01 \x01(\t\x12/\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32\x1f.eolymp.course.Enrollment.Extra\"I\n\x18\x44\x65scribeEnrollmentOutput\x12-\n\nenrollment\x18\x01 \x01(\x0b\x32\x19.eolymp.course.Enrollment2\xee\x06\n\x11\x45nrollmentService\x12\x9f\x01\n\x10\x43reateEnrollment\x12$.eolymp.course.CreateEnrollmentInput\x1a%.eolymp.course.CreateEnrollmentOutput\">\x82\xe3\n\x17\x8a\xe3\n\x13\x63ourse:course:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x0e\x1a\x0c/enrollments\x12\xaf\x01\n\x10UpdateEnrollment\x12$.eolymp.course.UpdateEnrollmentInput\x1a%.eolymp.course.UpdateEnrollmentOutput\"N\x82\xe3\n\x17\x8a\xe3\n\x13\x63ourse:course:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x1e\x1a\x1c/enrollments/{enrollment_id}\x12\xaf\x01\n\x10\x44\x65leteEnrollment\x12$.eolymp.course.DeleteEnrollmentInput\x1a%.eolymp.course.DeleteEnrollmentOutput\"N\x82\xe3\n\x17\x8a\xe3\n\x13\x63ourse:course:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x1e*\x1c/enrollments/{enrollment_id}\x12\xb4\x01\n\x12\x44\x65scribeEnrollment\x12&.eolymp.course.DescribeEnrollmentInput\x1a\'.eolymp.course.DescribeEnrollmentOutput\"M\x82\xe3\n\x16\x8a\xe3\n\x12\x63ourse:course:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x1e\x12\x1c/enrollments/{enrollment_id}\x12\x9b\x01\n\x0fListEnrollments\x12#.eolymp.course.ListEnrollmentsInput\x1a$.eolymp.course.ListEnrollmentsOutput\"=\x82\xe3\n\x16\x8a\xe3\n\x12\x63ourse:course:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x0e\x12\x0c/enrollmentsB/Z-github.com/eolymp/go-sdk/eolymp/course;courseb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.course.enrollment_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z-github.com/eolymp/go-sdk/eolymp/course;course'
  _ENROLLMENTSERVICE.methods_by_name['CreateEnrollment']._options = None
  _ENROLLMENTSERVICE.methods_by_name['CreateEnrollment']._serialized_options = b'\202\343\n\027\212\343\n\023course:course:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\016\032\014/enrollments'
  _ENROLLMENTSERVICE.methods_by_name['UpdateEnrollment']._options = None
  _ENROLLMENTSERVICE.methods_by_name['UpdateEnrollment']._serialized_options = b'\202\343\n\027\212\343\n\023course:course:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\036\032\034/enrollments/{enrollment_id}'
  _ENROLLMENTSERVICE.methods_by_name['DeleteEnrollment']._options = None
  _ENROLLMENTSERVICE.methods_by_name['DeleteEnrollment']._serialized_options = b'\202\343\n\027\212\343\n\023course:course:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\036*\034/enrollments/{enrollment_id}'
  _ENROLLMENTSERVICE.methods_by_name['DescribeEnrollment']._options = None
  _ENROLLMENTSERVICE.methods_by_name['DescribeEnrollment']._serialized_options = b'\202\343\n\026\212\343\n\022course:course:read\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002\036\022\034/enrollments/{enrollment_id}'
  _ENROLLMENTSERVICE.methods_by_name['ListEnrollments']._options = None
  _ENROLLMENTSERVICE.methods_by_name['ListEnrollments']._serialized_options = b'\202\343\n\026\212\343\n\022course:course:read\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002\016\022\014/enrollments'
  _CREATEENROLLMENTINPUT._serialized_start=290
  _CREATEENROLLMENTINPUT._serialized_end=360
  _CREATEENROLLMENTOUTPUT._serialized_start=362
  _CREATEENROLLMENTOUTPUT._serialized_end=409
  _UPDATEENROLLMENTINPUT._serialized_start=412
  _UPDATEENROLLMENTINPUT._serialized_end=644
  _UPDATEENROLLMENTINPUT_PATCH._serialized_start=566
  _UPDATEENROLLMENTINPUT_PATCH._serialized_end=644
  _UPDATEENROLLMENTOUTPUT._serialized_start=646
  _UPDATEENROLLMENTOUTPUT._serialized_end=670
  _DELETEENROLLMENTINPUT._serialized_start=672
  _DELETEENROLLMENTINPUT._serialized_end=718
  _DELETEENROLLMENTOUTPUT._serialized_start=720
  _DELETEENROLLMENTOUTPUT._serialized_end=744
  _LISTENROLLMENTSINPUT._serialized_start=747
  _LISTENROLLMENTSINPUT._serialized_end=1194
  _LISTENROLLMENTSINPUT_FILTER._serialized_start=1016
  _LISTENROLLMENTSINPUT_FILTER._serialized_end=1169
  _LISTENROLLMENTSINPUT_SORTABLE._serialized_start=1171
  _LISTENROLLMENTSINPUT_SORTABLE._serialized_end=1194
  _LISTENROLLMENTSOUTPUT._serialized_start=1196
  _LISTENROLLMENTSOUTPUT._serialized_end=1276
  _DESCRIBEENROLLMENTINPUT._serialized_start=1278
  _DESCRIBEENROLLMENTINPUT._serialized_end=1375
  _DESCRIBEENROLLMENTOUTPUT._serialized_start=1377
  _DESCRIBEENROLLMENTOUTPUT._serialized_end=1450
  _ENROLLMENTSERVICE._serialized_start=1453
  _ENROLLMENTSERVICE._serialized_end=2331
# @@protoc_insertion_point(module_scope)
