# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/course/enrollment.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x65olymp/course/enrollment.proto\x12\reolymp.course\x1a\x1fgoogle/protobuf/timestamp.proto\"\xc8\x03\n\nEnrollment\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tparent_id\x18\x02 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x03 \x01(\t\x12\x13\n\tmember_id\x18\n \x01(\tH\x00\x12\x12\n\x08group_id\x18\x0b \x01(\tH\x00\x12/\n\x0b\x65nrolled_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nexpires_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x39\n\x0b\x61ssignments\x18\x15 \x03(\x0b\x32$.eolymp.course.Enrollment.Assignment\x1a\x97\x01\n\nAssignment\x12\x11\n\tmodule_id\x18\x01 \x01(\t\x12/\n\x0bstart_after\x18\n \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x33\n\x0f\x63omplete_before\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x10\n\x08\x64uration\x18\x14 \x01(\r\"\x1a\n\x05\x45xtra\x12\x11\n\rUNKNOWN_EXTRA\x10\x00\x42\n\n\x08\x61ssigneeB/Z-github.com/eolymp/go-sdk/eolymp/course;courseb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.course.enrollment_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z-github.com/eolymp/go-sdk/eolymp/course;course'
  _ENROLLMENT._serialized_start=83
  _ENROLLMENT._serialized_end=539
  _ENROLLMENT_ASSIGNMENT._serialized_start=348
  _ENROLLMENT_ASSIGNMENT._serialized_end=499
  _ENROLLMENT_EXTRA._serialized_start=501
  _ENROLLMENT_EXTRA._serialized_end=527
# @@protoc_insertion_point(module_scope)
